@@ -100,9 +100,9 @@ class Domoticz(IPlugin):
 				log.msg("response   :  %s" % (jsonreq))
 				log.msg("*********************************************  : ")
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
-				total = len(jsonreq['result'])
-				log.msg(" len len   :  %s" % (total))	
-				for xx in len:
+				total = range(len(jsonreq['result']))
+				log.msg(" total    :  %s" % (total))	
+				for xx in total:
 					log.msg(" jsonreq - idx   :  %s" % (xx(idx)))
 					log.msg("   jsonreq - type   :  %s" % (xx(Type)))
 		if bodies == "":
